"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commandNames = void 0;
exports.rcOptionsTypes = rcOptionsTypes;
exports.cliOptionsTypes = cliOptionsTypes;
exports.help = help;
exports.handler = handler;
const path_1 = __importDefault(require("path"));
const promises_1 = __importDefault(require("fs/promises"));
const cli_utils_1 = require("@pnpm/cli-utils");
const plugin_commands_installation_1 = require("@pnpm/plugin-commands-installation");
const config_1 = require("@pnpm/config");
const error_1 = require("@pnpm/error");
const render_help_1 = __importDefault(require("render-help"));
const enquirer_1 = require("enquirer");
const pick_1 = __importDefault(require("ramda/src/pick"));
const updatePatchedDependencies_1 = require("./updatePatchedDependencies");
function rcOptionsTypes() {
    return (0, pick_1.default)([], config_1.types);
}
function cliOptionsTypes() {
    return { ...rcOptionsTypes() };
}
exports.commandNames = ['patch-remove'];
function help() {
    return (0, render_help_1.default)({
        description: 'Remove existing patch files',
        url: (0, cli_utils_1.docsUrl)('patch-remove'),
        usages: ['pnpm patch-remove [pkg...]'],
    });
}
async function handler(opts, params) {
    let patchesToRemove = params;
    const patchedDependencies = opts.patchedDependencies ?? {};
    if (!params.length) {
        const allPatches = Object.keys(patchedDependencies);
        if (allPatches.length) {
            ({ patches: patchesToRemove } = await (0, enquirer_1.prompt)({
                type: 'multiselect',
                name: 'patches',
                message: 'Select the patch to be removed',
                choices: allPatches,
                validate(value) {
                    return value.length === 0 ? 'Select at least one option.' : true;
                },
            }));
        }
    }
    if (!patchesToRemove.length) {
        throw new error_1.PnpmError('NO_PATCHES_TO_REMOVE', 'There are no patches that need to be removed');
    }
    const patchesDirs = new Set();
    await Promise.all(patchesToRemove.map(async (patch) => {
        if (Object.prototype.hasOwnProperty.call(patchedDependencies, patch)) {
            const patchFile = patchedDependencies[patch];
            patchesDirs.add(path_1.default.dirname(patchFile));
            await promises_1.default.rm(patchFile, { force: true });
            delete patchedDependencies[patch];
        }
    }));
    await Promise.all(Array.from(patchesDirs).map(async (dir) => {
        try {
            const files = await promises_1.default.readdir(dir);
            if (!files.length) {
                await promises_1.default.rmdir(dir);
            }
        }
        catch { }
    }));
    await (0, updatePatchedDependencies_1.updatePatchedDependencies)(patchedDependencies, {
        ...opts,
        workspaceDir: opts.workspaceDir ?? opts.rootProjectManifestDir,
    });
    return plugin_commands_installation_1.install.handler(opts);
}
//# sourceMappingURL=patchRemove.js.map